@@ -1,5 +1,8 @@
+import json
 from typing import Any, Dict
 
+from pydantic import BaseModel
+
 
 # Used for data-gplane role.
 AMAZON_S3_FULL_ACCESS_POLICY_NAME = "AmazonS3FullAccess"
@@ -412,6 +415,39 @@ ANYSCALE_SSM_READ_WRITE_ACCESS_POLICY_DOCUMENT = {
 }
 
 
+class AnyscaleIAMPolicy(BaseModel):
+    parameter_key: str
+    parameter_description: str
+    resource_logical_id: str
+    policy_name: str
+    policy_document: str
+
+
+ANYSCALE_IAM_POLICIES = [
+    AnyscaleIAMPolicy(
+        parameter_key="AnyscaleCrossAccountIAMPolicySteadyState",
+        parameter_description="Steady state IAM policy document",
+        resource_logical_id="IAMPermissionEC2SteadyState",
+        policy_name=ANYSCALE_IAM_POLICY_NAME_STEADY_STATE,
+        policy_document=json.dumps(ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE),
+    ),
+    AnyscaleIAMPolicy(
+        parameter_key="AnyscaleCrossAccountIAMPolicyServiceSteadyState",
+        parameter_description="Steady state IAM policy document for services",
+        resource_logical_id="IAMPermissionServiceSteadyState",
+        policy_name=ANYSCALE_IAM_POLICY_NAME_SERVICE_STEADY_STATE,
+        policy_document=json.dumps(ANYSCALE_IAM_PERMISSIONS_SERVICE_STEADY_STATE),
+    ),
+    AnyscaleIAMPolicy(
+        parameter_key="AnyscaleCrossAccountIAMPolicyInitialRun",
+        parameter_description="Initial run IAM policy document",
+        resource_logical_id="IAMPermissionEC2InitialRun",
+        policy_name=ANYSCALE_IAM_POLICY_NAME_INITIAL_RUN,
+        policy_document=json.dumps(ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN),
+    ),
+]
+
+
 def get_anyscale_aws_iam_assume_role_policy(
     anyscale_aws_account: str,
 ) -> Dict[str, Any]:
