@@ -1,13 +1,21 @@
+import contextlib
 from contextlib import contextmanager
 import os
 import sys
 import time
-from typing import Any, Optional
+from typing import Any, List, Optional
 
+from botocore.exceptions import ClientError
 import click
-import colorama  # type: ignore
+import colorama
 from halo import Halo
 
+from anyscale.client.openapi_client.models import (
+    CloudAnalyticsEventCloudProviderError,
+    CloudAnalyticsEventCloudResource,
+)
+from anyscale.utils.imports.gcp import try_import_gcp_exceptions
+
 
 _process_start_time = time.time()
 
@@ -245,3 +253,97 @@ class LogsLogger(BlockLogger):
             text=msg, spinner="dots", stream=sys.stderr, enabled=enable_spinner
         ) as spinner:
             yield spinner
+
+
+class CloudSetupLogger(LogsLogger):
+    def __init__(
+        self,
+        log_output: bool = True,
+        t0: float = _process_start_time,
+        spinner_manager: Any = None,
+    ):
+        self.cloud_resource_errors: List[CloudAnalyticsEventCloudProviderError] = []
+        super().__init__(log_output, t0, spinner_manager)
+
+    def log_resource_exception(
+        self, resource: CloudAnalyticsEventCloudResource, exc: Exception
+    ):
+        """
+        Record the error in the logger if the exception is an unhandled exception
+        """
+        if resource in (
+            CloudAnalyticsEventCloudResource.GCP_DEPLOYMENT,
+            CloudAnalyticsEventCloudResource.GCP_FILESTORE,
+            CloudAnalyticsEventCloudResource.GCP_FIREWALL_POLICY,
+            CloudAnalyticsEventCloudResource.GCP_PROJECT,
+            CloudAnalyticsEventCloudResource.GCP_SERVICE_ACCOUNT,
+            CloudAnalyticsEventCloudResource.GCP_STORAGE_BUCKET,
+            CloudAnalyticsEventCloudResource.GCP_SUBNET,
+            CloudAnalyticsEventCloudResource.GCP_VPC,
+            CloudAnalyticsEventCloudResource.GCP_WORKLOAD_IDENTITY_PROVIDER,
+        ):
+            # exceptions from GCP
+            GoogleAPICallError, HttpError = try_import_gcp_exceptions()
+            if isinstance(exc, GoogleAPICallError):
+                self.log_resource_error(
+                    resource, exc.reason, exc.code, "GoogleAPICallError",
+                )
+                return
+            elif isinstance(exc, HttpError):
+                reason = None
+                with contextlib.suppress(Exception):
+                    for error_detail in exc.error_details:
+                        if error_detail.get("reason"):
+                            reason = str(error_detail["reason"])
+                            break
+                self.log_resource_error(resource, reason, exc.status_code, "HttpError")
+                return
+        elif isinstance(exc, ClientError):
+            # boto3 client error
+            self.log_resource_error(
+                resource,
+                exc.response.get("Error", {}).get("Code"),
+                exc.response.get("ResponseMetadata", {}).get("HTTPStatusCode"),
+                "ClientError",
+            )
+            return
+        else:
+            unhandled_exception = f"UnknownExceptionType_{exc.__class__.__name__}"
+            self.log_resource_error(
+                resource, None, None, unhandled_exception,
+            )
+            return
+
+    def log_resource_error(
+        self,
+        cloud_resource: CloudAnalyticsEventCloudResource,
+        error_reason: Optional[str] = None,
+        status_code: Optional[int] = None,
+        unhandled_exception: Optional[str] = None,
+    ):
+        """
+        Append the error in the logger. If the error is already logged, it will be deduplicated.
+        """
+        formatted_error_str = error_reason if error_reason else "unknown"
+        if status_code:
+            formatted_error_str = f"{formatted_error_str},{status_code}"
+        if unhandled_exception:
+            formatted_error_str = f"{formatted_error_str},{unhandled_exception}"
+        for error in self.cloud_resource_errors:
+            if (
+                error.cloud_resource == cloud_resource
+                and error.error_code == formatted_error_str
+            ):
+                # deduplicated errors
+                return
+        self.cloud_resource_errors.append(
+            CloudAnalyticsEventCloudProviderError(
+                cloud_resource=cloud_resource, error_code=formatted_error_str
+            )
+        )
+
+    def get_cloud_provider_errors(self) -> List[CloudAnalyticsEventCloudProviderError]:
+        return self.cloud_resource_errors
+
+    def clear_cloud_provider_errors(self):
+        self.cloud_resource_errors = []
