@@ -136,7 +136,7 @@ def _get_subnets_from_subnet_ids(
     ]
 
 
-def verify_aws_subnets(  # noqa: PLR0911
+def verify_aws_subnets(  # noqa: PLR0911, PLR0912
     cloud_resource: CreateCloudResource,
     region: str,
     is_private_network: bool,
@@ -217,6 +217,13 @@ def verify_aws_subnets(  # noqa: PLR0911
             )
             if strict:
                 return False
+        if is_private_network and subnet.map_public_ip_on_launch:
+            logger.warning(
+                f"The private subnet {subnet_id} shouldn't have 'Auto-assign Public IP' option enabled."
+                "Please remove the `--private-network` flag if you don't want to deploy your Ray clusters in private subnets."
+            )
+            if strict:
+                return False
 
         # Success!
         logger.info(f"Subnet {subnet.id}'s verification succeeded.")
@@ -423,7 +430,24 @@ def verify_aws_iam_roles(  # noqa: PLR0911, PLR0912
     return True
 
 
-def verify_aws_security_groups(  # noqa: PLR0912
+def is_internal_communication_allowed(
+    ip_permissions: List, aws_security_group_ids: List[str]
+) -> bool:
+    """
+    This is a helper function to check if the security group allows internal communication.
+    It can be used for both inbound and outbound permissions.
+    """
+    sg_rule_with_self = []  # type: ignore
+    for sg_rule in ip_permissions:
+        if sg_rule.get("IpProtocol") == "-1":
+            sg_rule_with_self.extend(sg_rule.get("UserIdGroupPairs"))  # type: ignore
+    return any(
+        sg_rule.get("GroupId") in aws_security_group_ids
+        for sg_rule in sg_rule_with_self
+    )
+
+
+def verify_aws_security_groups(  # noqa: PLR0912, PLR0911
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
     logger: CloudSetupLogger,
@@ -467,16 +491,18 @@ def verify_aws_security_groups(  # noqa: PLR0912
         for anyscale_security_group in anyscale_security_groups
         for ip_permission in anyscale_security_group.ip_permissions
     ]
+    outbound_ip_permissions = [
+        ip_permission
+        for anyscale_security_group in anyscale_security_groups
+        for ip_permission in anyscale_security_group.ip_permissions_egress
+    ]
     inbound_ip_permissions_with_specific_port = {
         ip_permission["FromPort"]
         for ip_permission in inbound_ip_permissions
         if "FromPort" in ip_permission
     }
-    inbound_sg_rule_with_self = []  # type: ignore
-    for sg_rule in inbound_ip_permissions:
-        if sg_rule.get("IpProtocol") == "-1":
-            inbound_sg_rule_with_self.extend(sg_rule.get("UserIdGroupPairs"))  # type: ignore
 
+    # Check inbound permissions
     missing_open_ports = []
     for port in expected_open_ports:
         if not any(
@@ -491,9 +517,16 @@ def verify_aws_security_groups(  # noqa: PLR0912
         if strict:
             return False
 
-    if not any(
-        sg_rule.get("GroupId") in aws_security_group_ids
-        for sg_rule in inbound_sg_rule_with_self
+    if len(inbound_ip_permissions_with_specific_port) > len(expected_open_ports):
+        logger.warning(
+            f"Security groups {aws_security_group_ids} allows access to more than {expected_open_ports}. This may not be safe by default."
+        )
+        if strict:
+            return False
+
+    # Check internal communication is allowed
+    if not is_internal_communication_allowed(
+        inbound_ip_permissions, aws_security_group_ids
     ):
         logger.log_resource_error(
             CloudAnalyticsEventCloudResource.AWS_SECURITY_GROUP,
@@ -504,9 +537,13 @@ def verify_aws_security_groups(  # noqa: PLR0912
         )
         return False
 
-    if len(inbound_ip_permissions_with_specific_port) > len(expected_open_ports):
+    # Check outbound permissions
+    if not is_internal_communication_allowed(
+        outbound_ip_permissions, aws_security_group_ids
+    ):
         logger.warning(
-            f"Security groups {aws_security_group_ids} allows access to more than {expected_open_ports}. This may not be safe by default."
+            f"Security groups {aws_security_group_ids} do not contain outbound permission for all protocols for traffic from the same security group. "
+            f"This is required for certain network device such as EFA."
         )
         if strict:
             return False
@@ -871,9 +908,9 @@ def verify_aws_memorydb_cluster(  # noqa: PLR0911, PLR0912
             return False
 
         # verify that the subnet group has the same security group as the cloud
-        security_group_id = response["Clusters"][0]["SecurityGroups"][0][
-            "SecurityGroupId"
-        ]
+        security_group_id = response["Clusters"][0].get(
+            "SecurityGroups", [{"SecurityGroupId": "NOT_SPECIFIED"}]
+        )[0]["SecurityGroupId"]
         if security_group_id != cloud_resource.aws_security_groups[0]:
             logger.warning(
                 f"MemoryDB cluster {cloud_resource.memorydb_cluster_config.id} has security group {security_group_id} that is not the same as the cloud's security group {cloud_resource.aws_security_groups[0]}."
@@ -920,10 +957,10 @@ def verify_aws_memorydb_cluster(  # noqa: PLR0911, PLR0912
                 if strict:
                     return False
 
-        # verify TLS is disabled
-        if response["Clusters"][0]["TLSEnabled"]:
+        # verify TLS is enabled
+        if not response["Clusters"][0]["TLSEnabled"]:
             logger.error(
-                f"MemoryDB cluster {cloud_resource.memorydb_cluster_config.id} has TLS enabled which is not supported by ray. Please disable TLS for this cluster."
+                f"MemoryDB cluster {cloud_resource.memorydb_cluster_config.id} has TLS disabled. Please create a memorydb cluster with TLS enabled."
             )
             return False
 
