@@ -47,7 +47,9 @@ def get_default_cluster_compute(
 
 
 def get_cluster_compute_from_name(
-    cluster_compute_name: str, api_client: Optional[DefaultApi] = None,
+    cluster_compute_name: str,
+    api_client: Optional[DefaultApi] = None,
+    version: Optional[int] = None,
 ) -> ComputeTemplate:
     if api_client is None:
         api_client = get_auth_api_client().api_client
@@ -57,6 +59,7 @@ def get_cluster_compute_from_name(
             name={"equals": cluster_compute_name},
             include_anonymous=True,
             archive_status=ArchiveStatus.ALL,
+            version=version,
         )
     ).results
 
