@@ -9,7 +9,6 @@ import click
 from anyscale.authenticate import get_auth_api_client
 from anyscale.formatters import common_formatter
 from anyscale.sdk.anyscale_client import (
-    CreateSession,
     StartSessionOptions,
     TerminateSessionOptions,
     UpdateSession,
@@ -57,28 +56,6 @@ def get_session(session_id: str) -> None:
     print(common_formatter.prettify_json(response.to_dict()))
 
 
-@sessions.command(name="create", short_help="Creates a Session.")
-@click.argument("name", required=True)
-@click.argument("project_id", required=True)
-@click.argument("cloud_id", required=True)
-@click.argument("cluster_config", required=True)
-def create_session(
-    name: str, project_id: str, cloud_id: str, cluster_config: str,
-) -> None:
-    """Creates a Session with NAME, PROJECT_ID, CLOUD_ID, CLUSTER_CONFIG."""
-
-    api_client = get_auth_api_client().anyscale_api_client
-    create_data = CreateSession(
-        name=name,
-        cluster_config=cluster_config,
-        project_id=project_id,
-        cloud_id=cloud_id,
-    )
-    response = api_client.create_session(create_data)
-
-    print(common_formatter.prettify_json(response.to_dict()))
-
-
 @sessions.command(name="update", short_help="Updates a Session.")
 @click.argument("session_id", required=True)
 @click.argument("cluster_config", required=False)
