@@ -5,6 +5,7 @@ import click
 
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models import ClusterManagementStackVersions
+from anyscale.commands import cloud_commands_util
 from anyscale.commands.util import OptionPromptNull
 from anyscale.controllers.cloud_controller import CloudController
 
@@ -120,6 +121,9 @@ def cloud_set_default(
     default=False,
     help="Whether to enable head node fault tolerance for services.",
 )
+@click.option(
+    "--yes", "-y", is_flag=True, default=False, help="Skip asking for confirmation."
+)
 def setup_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
@@ -128,6 +132,7 @@ def setup_cloud(  # noqa: PLR0913
     functional_verify: Optional[str],
     anyscale_managed: bool,  # noqa: ARG001
     enable_head_node_fault_tolerance: bool,
+    yes: bool,
 ) -> None:
     # TODO (congding): remove `anyscale_managed` in the future, now keeping it for compatibility
     if provider == "aws":
@@ -138,6 +143,7 @@ def setup_cloud(  # noqa: PLR0913
             functional_verify=functional_verify,
             cluster_management_stack_version=ClusterManagementStackVersions.V2,
             enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
+            yes=yes,
         )
     elif provider == "gcp":
         if not project_id:
@@ -150,6 +156,7 @@ def setup_cloud(  # noqa: PLR0913
             functional_verify=functional_verify,
             cluster_management_stack_version=ClusterManagementStackVersions.V2,
             enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
+            yes=yes,
         )
 
 
@@ -200,11 +207,18 @@ def cloud_config_group() -> None:
     is_flag=False,
     flag_value="workspace",
 )
+@click.option(
+    "--enable-head-node-fault-tolerance",
+    is_flag=True,
+    default=False,
+    help="Whether to enable head node fault tolerance for services.",
+)
 def cloud_update(
     cloud_name: Optional[str],
     name: Optional[str],
     cloud_id: Optional[str],
     functional_verify: Optional[str],
+    enable_head_node_fault_tolerance: bool,
     yes: bool,
 ) -> None:
     if cloud_name and name and cloud_name != name:
@@ -215,6 +229,7 @@ def cloud_update(
     CloudController().update_managed_cloud(
         cloud_name=cloud_name or name,
         cloud_id=cloud_id,
+        enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
         functional_verify=functional_verify,
         yes=yes,
     )
@@ -480,10 +495,9 @@ def register_cloud(  # noqa: PLR0913
 
         if (
             memorystore_instance_name is not None
-            and re.search(
-                "projects/.+/locations/.+/instances/.+", memorystore_instance_name
+            and not cloud_commands_util.validate_memorystore_instance_name(
+                memorystore_instance_name
             )
-            is None
         ):
             raise click.ClickException(
                 "Please provide a valid memorystore instance name. Example: projects/<project number>/locations/<location>/instances/<instance id>"
@@ -577,6 +591,12 @@ def cloud_verify(
     required=False,
     type=str,
 )
+@click.option(
+    "--memorydb-cluster-id",
+    help="New AWS Memorydb cluster ID.",
+    required=False,
+    type=str,
+)
 @click.option(
     "--gcp-filestore-instance-id",
     help="New GCP filestore instance id.",
@@ -595,6 +615,12 @@ def cloud_verify(
     required=False,
     type=str,
 )
+@click.option(
+    "--memorystore-instance-name",
+    help="New Memorystore instance name for GCP clouds",
+    required=False,
+    type=str,
+)
 @click.option(
     "--functional-verify",
     help="Verify the cloud is functional. This will check that the cloud can launch workspace/service.",
@@ -609,9 +635,11 @@ def cloud_edit(  # noqa: PLR0913
     aws_s3_id: Optional[str],
     aws_efs_id: Optional[str],
     aws_efs_mount_target_ip: Optional[str],
+    memorydb_cluster_id: Optional[str],
     gcp_filestore_instance_id: Optional[str],
     gcp_filestore_location: Optional[str],
     gcp_cloud_storage_bucket_name: Optional[str],
+    memorystore_instance_name: Optional[str],
     functional_verify: Optional[str],
 ) -> None:
     if cloud_name and name and cloud_name != name:
@@ -624,9 +652,11 @@ def cloud_edit(  # noqa: PLR0913
             aws_s3_id,
             aws_efs_id,
             aws_efs_mount_target_ip,
+            memorydb_cluster_id,
             gcp_filestore_instance_id,
             gcp_filestore_location,
             gcp_cloud_storage_bucket_name,
+            memorystore_instance_name,
         ]
     ):
         if any([gcp_filestore_instance_id, gcp_filestore_location]) and not all(
@@ -636,18 +666,29 @@ def cloud_edit(  # noqa: PLR0913
             raise click.ClickException(
                 "Please provide both --gcp-filestore-instance-id and --gcp-filestore-location if you want to edit filestore."
             )
+        if (
+            memorystore_instance_name is not None
+            and not cloud_commands_util.validate_memorystore_instance_name(
+                memorystore_instance_name
+            )
+        ):
+            raise click.ClickException(
+                "Please provide a valid memorystore instance name. Example: projects/<project number>/locations/<location>/instances/<instance id>"
+            )
         CloudController().edit_cloud(
             cloud_name=cloud_name or name,
             cloud_id=cloud_id,
             aws_s3_id=aws_s3_id,
             aws_efs_id=aws_efs_id,
             aws_efs_mount_target_ip=aws_efs_mount_target_ip,
+            memorydb_cluster_id=memorydb_cluster_id,
             gcp_filestore_instance_id=gcp_filestore_instance_id,
             gcp_filestore_location=gcp_filestore_location,
             gcp_cloud_storage_bucket_name=gcp_cloud_storage_bucket_name,
+            memorystore_instance_name=memorystore_instance_name,
             functional_verify=functional_verify,
         )
     else:
         raise click.ClickException(
-            "Please provide at least one of the following arguments: --aws-s3-id, --aws-efs-id, --aws-efs-mount-target-ip, --gcp-filestore-instance-id, --gcp-filestore-location, --gcp-cloud-storage-bucket-name."
+            "Please provide at least one of the following arguments: --aws-s3-id, --aws-efs-id, --aws-efs-mount-target-ip, --memorydb-cluster-id, --gcp-filestore-instance-id, --gcp-filestore-location, --gcp-cloud-storage-bucket-name, --memorystore-instance-name."
         )
