@@ -192,8 +192,7 @@ class ClientBuilder:
             redacted_token = _redact_token(self._credentials)
             self._log.debug(f"Using credentials {redacted_token}")
             self._anyscale_sdk = AnyscaleSDK(
-                self._credentials,
-                anyscale.shared_anyscale_utils.conf.ANYSCALE_HOST + "/ext",
+                self._credentials, anyscale.shared_anyscale_utils.conf.ANYSCALE_HOST,
             )
             configure_open_api_client_headers(self._anyscale_sdk.api_client, "connect")
         api_client = auth_api_client.api_client
