@@ -77,12 +77,14 @@ class AuthController:
         os.chmod(self.path, CREDENTIALS_FILE_PERMISSIONS)
         self.log.log(f"Successfully fixed the permissions of {CREDENTIALS_FILE}")
 
-    def remove(self) -> None:
+    def remove(self, ask=True) -> None:
         # check if the file exists
         if not os.path.exists(self.path):
             raise click.ClickException("Credentials file does not exist.")
 
-        if not click.confirm(f"Are you sure you want to remove {CREDENTIALS_FILE}?"):
+        if ask and not click.confirm(
+            f"Are you sure you want to remove {CREDENTIALS_FILE}?"
+        ):
             self.log.log("Canceled")
             return
 
