@@ -2,6 +2,7 @@ import concurrent.futures
 from contextlib import contextmanager
 from datetime import datetime
 from enum import Enum
+import random
 import time
 from typing import Any, Callable, Dict, List, Optional, Set
 
@@ -28,7 +29,6 @@ from anyscale.client.openapi_client.models import (
     ServiceEventCurrentState,
     SessionState,
 )
-from anyscale.cluster_env import get_default_cluster_env_build
 from anyscale.controllers.base_controller import BaseController
 from anyscale.project import get_default_project
 from anyscale.sdk.anyscale_client.models import (
@@ -44,13 +44,14 @@ from anyscale.utils.cloud_utils import CloudEventProducer
 
 POLL_INTERVAL_SECONDS = 10
 WORKSPACE_VERIFICATION_TIMEOUT_MINUTES = 10
-SERVICE_VERIFICATION_TIMEOUT_MINUTES = 15  # for a single rollout
+SERVICE_VERIFICATION_TIMEOUT_MINUTES = 30  # for a single rollout
 
 # default values for cluster compute config
 MAXIMUM_UPTIME_MINUTES = 15
 IDLE_TERMINATION_MINUTES = 5
 HEAD_NODE_TYPE_AWS = "m5.xlarge"  # on demand price ~$0.20 per hour
 HEAD_NODE_TYPE_GCP = "n1-standard-2"  # on demand price ~$0.11 per hour
+CREATE_COMPUTE_CONFIG_TIMEOUT_SECONDS = 300  # 5 minutes
 
 
 class CloudFunctionalVerificationType(str, Enum):
@@ -158,33 +159,67 @@ class CloudFunctionalVerificationController(BaseController):
                 }
             }
 
-        cluster_compute = self.anyscale_api_client.create_cluster_compute(
-            CreateClusterCompute(
-                name=cluster_compute_name,
-                config=cluster_compute_config,
-                anonymous=True,
-            )
-        ).result
-        return cluster_compute.id
+        start_time = time.time()
+        end_time = start_time + CREATE_COMPUTE_CONFIG_TIMEOUT_SECONDS
+
+        delay = 1
+        max_delay = 64
+        while time.time() < end_time:
+            try:
+                cluster_compute = self.anyscale_api_client.create_cluster_compute(
+                    CreateClusterCompute(
+                        name=cluster_compute_name,
+                        config=cluster_compute_config,
+                        anonymous=True,
+                    )
+                ).result
+                return cluster_compute.id
+            except ClickException as e:
+                if "Stream removed" not in str(e):
+                    # "Stream removed" is a known issue that ingress for CM is not ready yet
+                    # We should retry here
+                    raise e
+            delay = min(delay, max_delay)
+            # Add jitter to avoid synchronized retries
+            jitter = random.uniform(0, delay / 2)
+            time.sleep(delay + jitter)
+            delay *= 2  # exponential backoff
+        raise ClickException(
+            "Timed out waiting for cluster compute to be created. Please try again."
+        )
 
     def _prepare_verification(self, cloud_id: str, cloud_provider: CloudProviders):
         """
         Generate the required parameters for cloud functional verification.
         """
-        cluster_compute_id = self.get_or_create_cluster_compute(
-            cloud_id, cloud_provider
-        )
 
-        cluster_env_build_id = get_default_cluster_env_build(
-            self.api_client, self.anyscale_api_client
-        ).id
+        cluster_env_build_id = self.get_default_cluster_env_build_id()
 
         project_id = get_default_project(
             self.api_client, self.anyscale_api_client, parent_cloud_id=cloud_id
         ).id
 
+        cluster_compute_id = self.get_or_create_cluster_compute(
+            cloud_id, cloud_provider
+        )
+
         return cluster_compute_id, cluster_env_build_id, project_id
 
+    def get_default_cluster_env_build_id(self):
+        try:
+            cluster_env_list = self.api_client.list_application_templates_api_v2_application_templates_get(
+                defaults_first=True
+            ).results
+            if len(cluster_env_list) == 0:
+                raise ClickException("No cluster environments found")
+        except Exception as e:  # noqa: BLE001
+            raise ClickException(f"Failed to list cluster environments: {e}")
+
+        for cluster_env in cluster_env_list:
+            if cluster_env.is_default:
+                return cluster_env.latest_build.id
+        return cluster_env_list[0].latest_build.id
+
     @contextmanager
     def _create_task(self, function: CloudFunctionalVerificationType, description: str):
         """
@@ -247,7 +282,7 @@ class CloudFunctionalVerificationController(BaseController):
                 return False
             url = get_endpoint(f"/workspaces/{workspace.id}/{workspace.cluster_id}")
             create_workspace_task.update(
-                True, f"[bold green]Workspace created at [link={url}]{url}[/link]"
+                True, f"[bold green]Workspace created at {url}"
             )
 
         # Wait until workspace is active
@@ -342,6 +377,7 @@ class CloudFunctionalVerificationController(BaseController):
         *,
         version: str = "v1",
         service_name: str = None,
+        canary_percent: Optional[int] = None,
     ):
         """
         Roll out a service for cloud functional verification
@@ -374,20 +410,23 @@ class CloudFunctionalVerificationController(BaseController):
             build_id=cluster_env_build_id,
             compute_config_id=cluster_compute_id,
             config=ServiceConfig(
-                max_uptime_timeout_sec=SERVICE_VERIFICATION_TIMEOUT_MINUTES * 60,
+                max_uptime_timeout_sec=SERVICE_VERIFICATION_TIMEOUT_MINUTES * 2 * 60,
             ),
+            canary_percent=canary_percent,
         )
 
         # Rollout service
-        service = self.api_client.apply_service_v2_api_v2_services_v2_apply_put(
+        service = self.api_client.apply_service_api_v2_services_v2_apply_put(
             service_config
         ).result
 
         return service
 
-    def verify_service(self, cloud_id: str, cloud_provider: CloudProviders) -> bool:
+    def verify_service(  # noqa: PLR0911
+        self, cloud_id: str, cloud_provider: CloudProviders
+    ) -> bool:
         """
-        Verifies that the service can be deployed and updated on the given cloud.
+        Verifies that the service can be deployed and upgraded on the given cloud.
         """
         # Deploy service
         with self._create_task(
@@ -406,9 +445,7 @@ class CloudFunctionalVerificationController(BaseController):
                 )
                 return False
             url = get_endpoint(f"/services/{service.id}")
-            deploy_service_task.update(
-                True, f"[bold green]Service deployed at [link={url}]{url}[/link]"
-            )
+            deploy_service_task.update(True, f"[bold green]Service deployed at {url}")
 
         # Wait until service is active
         def get_service_status(service_id):
@@ -416,11 +453,8 @@ class CloudFunctionalVerificationController(BaseController):
                 service_id
             ).result.current_state
 
-        allowed_status_set = {
-            ServiceEventCurrentState.RUNNING,
-            ServiceEventCurrentState.UPDATING,
-            ServiceEventCurrentState.STARTING,
-        }
+        # We add all service states into the set
+        allowed_status_set = set(ServiceEventCurrentState.allowable_values)
 
         with self._create_task(
             CloudFunctionalVerificationType.SERVICE,
@@ -449,13 +483,17 @@ class CloudFunctionalVerificationController(BaseController):
                 return False
             wait_task.update(True, "[bold green]Service is active.")
 
-        # Update service
+        # Upgrade service
         with self._create_task(
-            CloudFunctionalVerificationType.SERVICE, "Updating service..."
-        ) as update_service_task:
+            CloudFunctionalVerificationType.SERVICE, "Upgrading service..."
+        ) as upgrade_service_task:
             try:
                 service = self.rollout_service(
-                    cloud_id, cloud_provider, version="v2", service_name=service.name
+                    cloud_id,
+                    cloud_provider,
+                    version="v2",
+                    service_name=service.name,
+                    canary_percent=100,
                 )
             except ClickException as e:
                 self.cloud_event_producer.produce(
@@ -463,13 +501,11 @@ class CloudFunctionalVerificationController(BaseController):
                     succeeded=False,
                     internal_error=str(e),
                 )
-                update_service_task.update(
-                    False, f"[bold red]Failed to update service: {e}"
+                upgrade_service_task.update(
+                    False, f"[bold red]Failed to upgrade service: {e}"
                 )
                 return False
 
-            # Wait until service is active
-            allowed_status_set.add(ServiceEventCurrentState.ROLLING_OUT)
             try:
                 self.poll_until_active(
                     CloudFunctionalVerificationType.SERVICE,
@@ -477,7 +513,7 @@ class CloudFunctionalVerificationController(BaseController):
                     get_service_status,
                     ServiceEventCurrentState.RUNNING,
                     allowed_status_set,
-                    update_service_task,
+                    upgrade_service_task,
                     SERVICE_VERIFICATION_TIMEOUT_MINUTES,
                 )
             except ClickException as e:
@@ -486,12 +522,12 @@ class CloudFunctionalVerificationController(BaseController):
                     succeeded=False,
                     internal_error=str(e),
                 )
-                update_service_task.update(
+                upgrade_service_task.update(
                     False,
                     f"[bold red]Error: {e}. Please click on the URL above to check the logs.",
                 )
                 return False
-            update_service_task.update(
+            upgrade_service_task.update(
                 True, "[bold green]Service upgraded successfully."
             )
 
@@ -503,11 +539,6 @@ class CloudFunctionalVerificationController(BaseController):
                 self.api_client.terminate_service_api_v2_services_v2_service_id_terminate_post(
                     service.id
                 )
-                allowed_status_set = {
-                    ServiceEventCurrentState.TERMINATED,
-                    ServiceEventCurrentState.TERMINATING,
-                    ServiceEventCurrentState.RUNNING,
-                }
                 self.poll_until_active(
                     CloudFunctionalVerificationType.SERVICE,
                     service,
@@ -654,7 +685,7 @@ class CloudFunctionalVerificationController(BaseController):
 
     def _format_service_event_log(self, event_log: Any) -> str:
         description = event_log.message.replace("\n", ". ") if event_log.message else ""
-        return f"[bold cyan]{event_log.created_at}[/bold cyan] [bold blue]{event_log.event_type}[/bold blue] [bold red]{description}[/bold red]"
+        return f"[bold cyan]{event_log.created_at}[/bold cyan] [bold blue]{event_log.event_type}[/bold blue] [bold green]{description}[/bold green]"
 
     def _render_event_log(
         self, function_type: CloudFunctionalVerificationType, function: Any
