@@ -15,7 +15,7 @@ from anyscale.client.openapi_client.models.decorated_production_service_v2_api_m
 )
 from anyscale.client.openapi_client.models.ha_job_states import HaJobStates
 from anyscale.controllers.base_controller import BaseController
-from anyscale.formatters.service_formatter import format_service_config_v2
+from anyscale.formatters.service_formatter import format_service_config
 from anyscale.models.service_model import ServiceConfig
 from anyscale.project import infer_project_id
 from anyscale.tables import ServicesTable
@@ -267,9 +267,9 @@ class ServiceController(BaseController):
 
         self._overwrite_runtime_env_in_v2_ray_serve_config(config)
 
-        service_v2_config = format_service_config_v2(config)
+        service_v2_config = format_service_config(config)
 
-        service = self.api_client.apply_service_v2_api_v2_services_v2_apply_put(
+        service = self.api_client.apply_service_api_v2_services_v2_apply_put(
             service_v2_config
         ).result
 
@@ -284,9 +284,7 @@ class ServiceController(BaseController):
         if config.canary_percent is not None and len(service.versions) > 1:
             if config.canary_percent == 100:
                 self.log.warning(
-                    "The canary percent has been set to 100%. NOTE that this will not complete the rollout. "
-                    "To complete the rollout, you will need to trigger an automatic rollout for the service. "
-                    "This can be achieved by removing the canary percent flag and executing the rollout command again."
+                    "The canary percent has been set to 100%. This will complete the rollout."
                 )
             self._log_canary_version_query(service)
 
