@@ -137,6 +137,7 @@ def _vpc_has_proxy_only_subnet(
 
 def verify_gcp_project(  # noqa: PLR0911
     factory: GoogleCloudClientFactory,
+    resources: CreateCloudResourceGCP,
     project_id: str,
     logger: GCPLogger,
     strict: bool = False,
@@ -179,13 +180,15 @@ def verify_gcp_project(  # noqa: PLR0911
 
     # Verify that APIs are Enabled
     service_usage_client = factory.build("serviceusage", "v1")
+    if resources.memorystore_instance_config is not None:
+        apis = GCP_REQUIRED_APIS + ["redis.googleapis.com"]  # Memorystore for Redis
+    else:
+        apis = GCP_REQUIRED_APIS
     response = (
         service_usage_client.services()
         .batchGet(
             parent=f"projects/{project_id}",
-            names=[
-                f"projects/{project_id}/services/{api}" for api in GCP_REQUIRED_APIS
-            ],
+            names=[f"projects/{project_id}/services/{api}" for api in apis],
         )
         .execute()
     )
@@ -667,7 +670,7 @@ def _check_bucket_region(bucket: Bucket, region: str) -> Tuple[bool, str]:
     return region.upper().startswith(bucket.location), bucket.location
 
 
-def verify_memorystore(
+def verify_memorystore(  # noqa: PLR0911
     factory: GoogleCloudClientFactory,
     resources: CreateCloudResourceGCP,
     logger: GCPLogger,
@@ -725,4 +728,11 @@ def verify_memorystore(
         )
         return False
 
+    # Verify that the memorystore has tls disabled
+    if redis_instance.transit_encryption_mode.name != "DISABLED":
+        logger.internal.error(
+            "Memorystore has TLS enabled. Please create a new memorystore instance with TLS disabled."
+        )
+        return False
+
     return True
