@@ -433,7 +433,7 @@ def get_default_project(
     return default_project
 
 
-def infer_project_id(
+def infer_project_id(  # noqa PLR0913
     anyscale_api_client: DefaultApi,
     api_client: DefaultApi,
     log: BlockLogger,
@@ -441,6 +441,7 @@ def infer_project_id(
     cluster_compute_id: Optional[str] = None,
     cluster_compute: Optional[Union[str, Dict[str, Any]]] = None,
     cloud: Optional[str] = None,
+    cluster_compute_version: Optional[int] = None,
 ) -> str:
     if not project_id:
         # Check directory of .anyscale.yaml to decide whether to use default project.
@@ -452,7 +453,7 @@ def infer_project_id(
             # TODO: add cloud compute config args here
             if not cluster_compute_id and isinstance(cluster_compute, str):
                 cluster_compute_id = get_cluster_compute_from_name(
-                    cluster_compute, api_client
+                    cluster_compute, api_client, cluster_compute_version
                 ).id
             cluster_compute_config = (
                 ClusterComputeConfig(**cluster_compute)
