@@ -17,10 +17,12 @@ from anyscale.commands.exec_commands import anyscale_exec
 from anyscale.commands.experimental_integrations_commands import (
     experimental_integrations_cli,
 )
+from anyscale.commands.fine_tune_commands import fine_tune_cli
 from anyscale.commands.job_commands import job_cli
 from anyscale.commands.list_commands import list_cli
 from anyscale.commands.login_commands import anyscale_login, anyscale_logout
 from anyscale.commands.logs_commands import log_cli
+from anyscale.commands.machine_commands import machine_cli
 from anyscale.commands.migrate_commands import migrate_cli
 from anyscale.commands.project_commands import anyscale_init, project_cli
 from anyscale.commands.schedule_commands import schedule_cli
@@ -112,6 +114,7 @@ cli.add_command(cluster_cli)
 cli.add_command(workspace_cli)
 cli.add_command(experimental_integrations_cli)
 cli.add_command(auth_cli)
+cli.add_command(fine_tune_cli)
 
 cli.add_command(anyscale_init)
 cli.add_command(anyscale_exec)
@@ -124,6 +127,7 @@ cli.add_command(anyscale_api)
 cli.add_command(log_cli)
 cli.add_command(anyscale_login)
 cli.add_command(anyscale_logout)
+cli.add_command(machine_cli)
 
 ALIASES = {
     "h": anyscale_help,
