@@ -10,22 +10,16 @@ from anyscale.api import configure_tcp_keepalive
 from anyscale.api_utils.job_logs_util import (
     _get_logs_from_running_production_job,
     _get_job_logs_from_storage_bucket,
-    _get_logs_from_active_job_run,
 )
 from anyscale.api_utils.exceptions.log_retrieval_errors import (
     ExpectedLogRetrievalError,
-    LogRetrievalTimeoutError,
-    UnsupportedLogRetrievalMethodError,
 )
-from anyscale.api_utils.logs_util import _remove_ansi_escape_sequences
 from anyscale.sdk.anyscale_client.models.cluster_compute_config import (
     ClusterComputeConfig,
 )
 from anyscale.sdk.anyscale_client.models.create_cluster_compute import (
     CreateClusterCompute,
 )
-from anyscale.sdk.anyscale_client.models.job import Job
-from anyscale.sdk.anyscale_client.models.job_status import JobStatus
 from anyscale.sdk.anyscale_client.models.production_job import ProductionJob
 from anyscale.sdk.anyscale_client.models.ha_job_states import HaJobStates
 from anyscale.utils.runtime_env import upload_and_rewrite_working_dir
@@ -38,9 +32,6 @@ from anyscale.sdk.anyscale_client.models.create_cluster_environment import (
 from anyscale.sdk.anyscale_client.models.create_byod_cluster_environment import (
     CreateBYODClusterEnvironment,
 )
-from anyscale.sdk.anyscale_client.models.apply_production_service_v2_model import (
-    ApplyProductionServiceV2Model,
-)
 from anyscale.sdk.anyscale_client.models.cluster import Cluster
 from anyscale.sdk.anyscale_client.models.cluster_state import ClusterState
 from anyscale.sdk.anyscale_client.models.update_cluster import UpdateCluster
@@ -55,8 +46,8 @@ from anyscale.util import get_endpoint
 from anyscale.authenticate import AuthenticationBlock
 from anyscale_client.models import ClusterEnvironmentBuildStatus
 from anyscale.util import get_ray_and_py_version_for_default_cluster_env
-from anyscale.utils.deprecation_util import deprecated
 from anyscale.project import get_default_project
+from anyscale.utils.ray_version_utils import get_correct_name_for_base_image_name
 
 logger = logging.getLogger(__file__)
 
@@ -133,10 +124,14 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         if host is None:
             host = os.environ.get("ANYSCALE_HOST", "https://api.anyscale.com")
 
-        # Special handling for `console.` host names
+        # Automatically convert anyscale host to host for anyscale external api
         if host.startswith("https://console."):
             host = host.replace("console.", "api.", 1)
 
+        # Automatically convert anyscale host to host for anyscale external api (premerge)
+        if host.startswith("https://ci-"):
+            host = host.rstrip("/") + "/ext"
+
         # Adds base path "v0" for API endpoints
         endpoint_url = host.rstrip("/") + "/v0"
         configuration = anyscale_client.Configuration(host=endpoint_url)
@@ -198,6 +193,11 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                     create_cluster_environment
                 ).result
             else:
+                base_image_name = create_cluster_environment.config_json['base_image']
+                correct_base_image_name = get_correct_name_for_base_image_name(base_image_name)
+                if base_image_name != correct_base_image_name: # We need to make sure base_image_name after ray 2.7.0, before 2.8.0 have a optimized suffix
+                    self.log.error(f"Starting from Ray version 2.7.0 and before version 2.8.0, you might be required to include the suffix 'optimized' in the base_image name for that specific Ray version. Try using {self.log.highlight(correct_base_image_name)}")
+                    return
                 cluster_environment = self.create_cluster_environment(
                     create_cluster_environment
                 ).result
@@ -218,6 +218,11 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                     }
                 ).result
             else:
+                base_image_name = create_cluster_environment.config_json['base_image']
+                correct_base_image_name = get_correct_name_for_base_image_name(base_image_name)
+                if base_image_name != correct_base_image_name: # We need to make sure base_image_name after ray 2.7.0, before 2.8.0 have a optimized suffix
+                    self.log.error(f"Starting from Ray version 2.7.0 and before version 2.8.0, you might be required to include the suffix 'optimized' in the base_image name for that specific Ray version. Try using {self.log.highlight(correct_base_image_name)}")
+                    return
                 build = self.create_cluster_environment_build(
                     {
                         "cluster_environment_id": cluster_environment.id,
@@ -519,7 +524,6 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         else:
             return self.get_cluster(operation.cluster_id).result
 
-
     def fetch_production_job_logs(self, job_id: str) -> str:
         """
         Retrieves logs for a job (eg. 'prodjob_123').
@@ -572,9 +576,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
 
     def rollout_service_v2(self, apply_production_service_v2_model, **kwargs):
         """
-        If a local working_dir and upload_path are specified in ray_serve_config,
-        this method uploads the local working_dir to the upload_path and rewrites
-        the working_dir in ray_serve_config.
+        DEPRECATED. Please use rollout_service.
         """
         if isinstance(apply_production_service_v2_model, dict):
             ray_serve_config = apply_production_service_v2_model.get("ray_serve_config")
@@ -590,6 +592,27 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             apply_production_service_v2_model.ray_serve_config = new_ray_serve_config
 
         return super().rollout_service_v2(apply_production_service_v2_model, **kwargs)
+    
+    def rollout_service(self, apply_service_model, **kwargs):
+        """
+        If a local working_dir and upload_path are specified in ray_serve_config,
+        this method uploads the local working_dir to the upload_path and rewrites
+        the working_dir in ray_serve_config.
+        """
+        if isinstance(apply_service_model, dict):
+            ray_serve_config = apply_service_model.get("ray_serve_config")
+            new_ray_serve_config = _upload_and_rewrite_working_dir_ray_serve_config(
+                ray_serve_config
+            )
+            apply_service_model["ray_serve_config"] = new_ray_serve_config
+        elif hasattr(apply_service_model, "ray_serve_config"):
+            ray_serve_config = apply_service_model.ray_serve_config
+            new_ray_serve_config = _upload_and_rewrite_working_dir_ray_serve_config(
+                ray_serve_config
+            )
+            apply_service_model.ray_serve_config = new_ray_serve_config
+
+        return super().rollout_service(apply_service_model, **kwargs)
 
     def get_cluster_token(self, project_id: str, cluster_name: str) -> str:
         """
