@@ -25,6 +25,7 @@ WORKING_DIR = os.environ.get("ANYSCALE_WORKING_DIR", "/home/ray")
 CONFIGS_TO_SAVE = [
     ".bash_history",
     ".zsh_history",
+    ".python_history",
 ]
 # These files are saved per user.
 CONFIGS_TO_REPLICATE = [
@@ -774,19 +775,6 @@ def env_hook(runtime_env) -> Dict[str, Any]:
     return runtime_env
 
 
-def job_hook(**kwargs):
-    """Job hook to tell users to use normal commands or anyscale job submit.
-
-    This should be set as `RAY_JOB_SUBMIT_HOOK=anyscale.snapshot_util.job_hook`.
-    """
-    cmd = " ".join(kwargs["entrypoint"])
-    raise ValueError(
-        f"`ray job submit` is not needed within a workspace. Run `{cmd}` "
-        f"directly to execute the job in the current cluster. To run on a new "
-        f"cluster, use `anyscale job submit -- {cmd}`."
-    )
-
-
 def setup_credentials():
     """Command to create SSH credentials for the workspace.
 
