@@ -60,6 +60,8 @@ PROJECT_NAME_ENV_VAR = "ANYSCALE_PROJECT_NAME"
 
 VALID_BYOD_PYTHON_VERSIONS = ["py36", "py37", "py38", "py39"]
 
+REDIS_TLS_ADDRESS_PREFIX = "rediss://"
+
 log = BlockLogger()  # Anyscale CLI Logger
 
 VPC_CIDR_RANGE = "10.0.0.0/16"
@@ -71,6 +73,55 @@ DEFAULT_RAY_VERSION = "1.7.0"
 # grace period before erroring.
 TERMINATED_STATE_GRACE_PERIOD_SECONDS = 60
 
+MEMORY_DB_OUTPUT = """  MemoryDB:
+    Description: MemoryDB cluster
+    Value:
+      Fn::ToJsonString:
+        arn: !GetAtt MemoryDB.ARN
+        ClusterEndpointAddress: !GetAtt MemoryDB.ClusterEndpoint.Address"""
+
+MEMORY_DB_RESOURCE = """  MemoryDBSubnetGroup:
+    Type: AWS::MemoryDB::SubnetGroup
+    Properties:
+      Description: Anyscale managed MemoryDB subnet group
+      SubnetGroupName: !Ref AWS::StackName
+      SubnetIds:
+{}
+      Tags:
+        - Key: anyscale-cloud-id
+          Value: !Ref CloudID
+
+  MemoryDBParameterGroup:
+    Type: AWS::MemoryDB::ParameterGroup
+    Properties:
+      Description: Parameter group for anyscale managed MemoryDB
+      Family: memorydb_redis7
+      ParameterGroupName:  !Ref AWS::StackName
+      Tags:
+        - Key: anyscale-cloud-id
+          Value: !Ref CloudID
+
+  MemoryDB:
+    Type: AWS::MemoryDB::Cluster
+    Properties:
+      ACLName: open-access
+      Description: Anyscale managed MemoryDB
+      ClusterName: !Ref AWS::StackName
+      NodeType: db.t4g.small
+      Port: !Ref MemoryDBRedisPort
+      SubnetGroupName: !Ref MemoryDBSubnetGroup
+      SecurityGroupIds:
+        - !Ref AnyscaleSecurityGroup
+      EngineVersion: "7.0"
+      ParameterGroupName: !Ref MemoryDBParameterGroup
+      TLSEnabled: true
+      Tags:
+        - Key: anyscale-cloud-id
+          Value: !Ref CloudID"""
+
+# Some resources (e.g. memorystore) take a long time to create, so we need to increase the timeout.
+GCP_DEPLOYMENT_MANAGER_TIMEOUT_SECONDS_LONG = 600  # 10 minutes
+
 
 def confirm(msg: str, yes: bool) -> Optional[bool]:
     return None if yes else click.confirm(msg, abort=True)
@@ -210,9 +261,7 @@ def _get_role(role_name: str, region: str) -> Optional[Boto3Resource]:
             raise exc
 
 
-def _get_aws_efs_mount_target_ip(
-    boto3_session: Any, efs_id: str, cloud_setup_logger: CloudSetupLogger
-) -> Optional[str]:
+def _get_aws_efs_mount_target_ip(boto3_session: Any, efs_id: str) -> Optional[str]:
     client = boto3_session.client("efs")
     try:
         mount_targets_response = client.describe_mount_targets(FileSystemId=efs_id)
@@ -223,9 +272,6 @@ def _get_aws_efs_mount_target_ip(
     except ClientError as e:
         if e.response["Error"]["Code"] == "FileSystemNotFound":
             return None
-        cloud_setup_logger.log_resource_exception(
-            CloudAnalyticsEventCloudResource.AWS_EFS, e
-        )
         raise e
 
 
@@ -269,9 +315,19 @@ def _get_memorydb_cluster_config(
                 f"MemoryDB cluster with id {memorydb_cluster_id} does not exist."
             )
         cluster = response["Clusters"][0]
+        if cluster["Status"] != "available":
+            logger.log_resource_error(
+                CloudAnalyticsEventCloudResource.AWS_MEMORYDB,
+                CloudSetupError.MEMORYDB_CLUSTER_UNAVAILABLE,
+            )
+            raise click.ClickException(
+                f"MemoryDB cluster with id {memorydb_cluster_id} is not currently available. Please make sure the cluster is available and try again."
+            )
         endpoint = cluster["ClusterEndpoint"]
+
         return AWSMemoryDBClusterConfig(
-            id=cluster["ARN"], endpoint=f"{endpoint['Address']}:{endpoint['Port']}",
+            id=cluster["ARN"],
+            endpoint=f"{REDIS_TLS_ADDRESS_PREFIX}{endpoint['Address']}:{endpoint['Port']}",
         )
     except ClientError as e:
         if e.response["Error"]["Code"] == "ClusterNotFoundFault":
@@ -796,56 +852,12 @@ def prepare_cloudformation_template(
     )
 
     if enable_head_node_fault_tolerance:
-        body = body.replace(
-            "$MEMORY_DB_OUTPUT",
-            """  MemoryDB:
-    Description: MemoryDB cluster
-    Value:
-      Fn::ToJsonString:
-        arn: !GetAtt MemoryDB.ARN
-        ClusterEndpointAddress: !GetAtt MemoryDB.ClusterEndpoint.Address""",
-        )
-        # chr(10) is a newline (\n) since f-string expression part cannot include a backslash
+        body = body.replace("$MEMORY_DB_OUTPUT", MEMORY_DB_OUTPUT,)
         body = body.replace(
             "$MEMORY_DB_RESOURCE",
-            f"""  MemoryDBSubnetGroup:
-    Type: AWS::MemoryDB::SubnetGroup
-    Properties:
-      Description: Anyscale managed MemoryDB subnet group
-      SubnetGroupName: !Ref AWS::StackName
-      SubnetIds:
-{chr(10).join([f"        - !Ref Subnet{i}" for i in range(len(azs))])}
-      Tags:
-        - Key: anyscale-cloud-id
-          Value: !Ref CloudID
-
-  MemoryDBParameterGroup:
-    Type: AWS::MemoryDB::ParameterGroup
-    Properties:
-      Description: Parameter group for anyscale managed MemoryDB
-      Family: memorydb_redis7
-      ParameterGroupName:  !Ref AWS::StackName
-      Tags:
-        - Key: anyscale-cloud-id
-          Value: !Ref CloudID
-
-  MemoryDB:
-    Type: AWS::MemoryDB::Cluster
-    Properties:
-      ACLName: open-access
-      Description: Anyscale managed MemoryDB
-      ClusterName: !Ref AWS::StackName
-      NodeType: db.t4g.small
-      Port: !Ref MemoryDBRedisPort
-      SubnetGroupName: !Ref MemoryDBSubnetGroup
-      SecurityGroupIds:
-        - !Ref AnyscaleSecurityGroup
-      EngineVersion: "7.0"
-      ParameterGroupName: !Ref MemoryDBParameterGroup
-      TLSEnabled: false
-      Tags:
-        - Key: anyscale-cloud-id
-          Value: !Ref CloudID""",
+            MEMORY_DB_RESOURCE.format(
+                "\n".join([f"        - !Ref Subnet{i}" for i in range(len(azs))])
+            ),
         )
     else:
         body = body.replace("$MEMORY_DB_OUTPUT", "")
