@@ -1,6 +1,7 @@
 import contextlib
 from enum import Enum
 import sys
+import time
 from typing import Optional, Tuple
 import uuid
 
@@ -106,6 +107,26 @@ def modify_memorydb_parameter_group(parameter_group_name: str, region: str) -> N
         )
 
 
+def wait_for_lb_resource_termination(
+    api_client: DefaultApi,
+    cloud_id: str,
+    timeout_s: int = 900,  # 15 minute timeout
+    poll_interval_s: int = 10,  # Poll every 10 seconds
+):
+    start = time.time()
+    while time.time() - start < timeout_s:
+        response = api_client.get_lb_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_get_lb_resource_post(
+            cloud_id=cloud_id
+        ).result
+        if response.is_terminated:
+            break
+        time.sleep(poll_interval_s)
+    else:
+        raise ClickException(
+            f"LB resources and namespace termination timed out after {timeout_s} seconds."
+        )
+
+
 class CloudSetupError(str, Enum):
     ANYSCALE_ACCESS_DENIED = "ANYSCALE_ACCESS_DENIED"
     RESOURCE_NOT_FOUND = "RESOURCE_NOT_FOUND"
@@ -128,6 +149,7 @@ class CloudSetupError(str, Enum):
     FILESTORE_NOT_CONNECTED_TO_VPC = "FILESTORE_NOT_CONNECTED_TO_VPC"
     MEMORYSTORE_NOT_CONNECTED_TO_VPC = "MEMORYSTORE_NOT_CONNECTED_TO_VPC"
     MEMORYSTORE_READ_REPLICAS_DISABLED = "MEMORYSTORE_READ_REPLICAS_DISABLED"
+    MEMORYDB_CLUSTER_UNAVAILABLE = "MEMORYDB_CLUSTER_UNAVAILABLE"
 
 
 class CloudEventProducer:
@@ -135,10 +157,11 @@ class CloudEventProducer:
     Produce events during cloud setup/register/verify
     """
 
-    def __init__(self, api_client: DefaultApi):
+    def __init__(self, cli_version: str, api_client: DefaultApi):
         self.api_client = api_client
         self.cloud_id: Optional[str] = None
         self.cloud_provider: Optional[CloudProviders] = None
+        self.cli_version = cli_version
 
     def init_trace_context(
         self,
@@ -180,6 +203,7 @@ class CloudEventProducer:
             self.api_client.produce_analytics_event_api_v2_analytics_post(
                 CreateAnalyticsEvent(
                     cloud_analytics_event=CloudAnalyticsEvent(
+                        cli_version=self.cli_version,
                         trace_id=self.trace_id,
                         cloud_id=self.cloud_id,
                         succeeded=succeeded,
