@@ -1,7 +1,7 @@
 import os
 from string import Template
 import time
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 from click import ClickException
 from google.api_core.exceptions import BadRequest, Forbidden, NotFound, PermissionDenied
@@ -13,15 +13,46 @@ from google.cloud.compute_v1.types import (
 from google.iam.v1.iam_policy_pb2 import SetIamPolicyRequest
 from google.iam.v1.policy_pb2 import Binding
 from googleapiclient.errors import HttpError
+from pydantic import BaseModel
 import yaml
 
 from anyscale.cli_logger import CloudSetupLogger
 from anyscale.client.openapi_client.models import CloudAnalyticsEventCloudResource
 import anyscale.conf
 import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
+from anyscale.util import confirm, GCP_DEPLOYMENT_MANAGER_TIMEOUT_SECONDS_LONG
 from anyscale.utils.gcp_utils import GCP_REQUIRED_APIS, GoogleCloudClientFactory
 
 
+GCP_DEPLOYMENT_PREVIEW_TIMEOUT_SECONDS = 300  # 5 minutes
+
+
+GCP_MEMORYSTORE_RESOURCE_CONFIG_TEMPLATE = """
+- name: redis-${CLOUD_ID}
+  type: gcp-types/redis-v1:projects.locations.instances
+  properties:
+    parent: projects/${PROJECT_ID}/locations/${REGION}
+    instanceId: redis-${CLOUD_ID}
+    authorizedNetwork: projects/${PROJECT_ID}/global/networks/$$(ref.vpc-${CLOUD_ID}.name)
+    memorySizeGb: 5
+    replicaCount: 1
+    readReplicasMode: READ_REPLICAS_ENABLED
+    tier: STANDARD_HA
+    redisVersion: REDIS_7_0
+    displayName: redis-${CLOUD_ID}
+    redisConfigs:
+        maxmemory-policy: allkeys-lru
+  metadata:
+   dependsOn:
+     - subnet-${CLOUD_ID}"""
+
+
+class GCPDeployment(BaseModel):
+    deployment_name: str
+    fingerprint: str
+    config_content: str
+
+
 def get_project_number(factory: GoogleCloudClientFactory, project_id: str):
     project_client = factory.resourcemanager_v3.ProjectsClient()
     try:
@@ -125,22 +156,11 @@ def get_deployment_resources(
     project_id: str,
     anyscale_access_service_account_name: str,
 ):
-    try:
-        deployment_client = factory.build("deploymentmanager", "v2")
-        manifest = (
-            deployment_client.deployments()
-            .get(project=project_id, deployment=deployment_name)
-            .execute()["manifest"]
-        )
-        manifest_name = manifest.split("/")[-1]
-        manifest = (
-            deployment_client.manifests()
-            .get(project=project_id, deployment=deployment_name, manifest=manifest_name)
-            .execute()
-        )
-        config = yaml.safe_load(manifest["config"]["content"])
-    except HttpError as e:
-        raise ClickException(f"Failed to get deployment {deployment_name}. {e}")
+    """
+    Get the resources in a deployment.
+    """
+    gcp_deployment = get_deployment_config(factory, project_id, deployment_name)
+    config = yaml.safe_load(gcp_deployment.config_content)
 
     # TODO (congding): use a pydantic model instead of dict
     cloud_resources = {}
@@ -284,39 +304,25 @@ def generate_deployment_manager_config(  # noqa: PLR0913
     zone: str = "b",  # some regions like us-east1 or europe-west1 don't have zone "a"
     fileshare_capacity_gb: int = 1024,
 ) -> str:
-    cloud_id = cloud_id.replace("_", "-").lower()
-
+    """
+    Generate the deployment manager config for Anyscale cloud setup.
+    """
     with open(
         os.path.join(anyscale.conf.ROOT_DIR_PATH, "anyscale-cloud-setup-gcp.yaml")
     ) as f:
         body = f.read()
 
     if enable_head_node_fault_tolerance:
-        body += """
-- name: redis-${CLOUD_ID}
-  type: gcp-types/redis-v1:projects.locations.instances
-  properties:
-    parent: projects/${PROJECT_ID}/locations/${REGION}
-    instanceId: redis-${CLOUD_ID}
-    authorizedNetwork: projects/${PROJECT_ID}/global/networks/$$(ref.vpc-${CLOUD_ID}.name)
-    memorySizeGb: 5
-    replicaCount: 1
-    readReplicasMode: READ_REPLICAS_ENABLED
-    tier: STANDARD_HA
-    redisVersion: REDIS_7_0
-    displayName: redis-${CLOUD_ID}
-    redisConfigs:
-        maxmemory-policy: allkeys-lru
-  metadata:
-   dependsOn:
-     - subnet-${CLOUD_ID}
-"""
+        body += GCP_MEMORYSTORE_RESOURCE_CONFIG_TEMPLATE
     deployment_manager_config = Template(body)
 
     params = {
         "ANYSCALE_HOST": shared_anyscale_conf.ANYSCALE_HOST,
         "REGION": region,
-        "CLOUD_ID": cloud_id,
+        # `cloud_id` is used as the deployment name, which cannot contain underscores.
+        "CLOUD_ID": cloud_id.replace("_", "-").lower(),
+        # `cloud_id_underscore` is used as the the label values, which should be consistent with GCE instances.
+        "CLOUD_ID_UNDERSCORE": cloud_id,
         "PROJECT_ID": project_id,
         "ANYSCALE_ACCESS_SERVICE_ACCOUNT": anyscale_access_service_account_name,
         "WORKLOAD_IDENTITY_POOL_NAME": workload_identity_pool_name,
@@ -488,7 +494,7 @@ def delete_gcp_deployment(
 
 
 def update_deployment_with_bucket_only(
-    factory: GoogleCloudClientFactory, project_id: str, deployment_name: str
+    factory: GoogleCloudClientFactory, project_id: str, deployment_name: str,
 ):
     """
     Update all resources in the deployment except the bucket.
@@ -496,54 +502,23 @@ def update_deployment_with_bucket_only(
     See https://cloud.google.com/deployment-manager/docs/reference/latest/deployments/update
     """
     # update the deployment with only the bucket
-    deployment_client = factory.build("deploymentmanager", "v2")
-    try:
-        # get the deployment
-        deployment = (
-            deployment_client.deployments()
-            .get(project=project_id, deployment=deployment_name)
-            .execute()
-        )
-        fingerprint = deployment["fingerprint"]
-        manifest = deployment["manifest"]
-        manifest_name = manifest.split("/")[-1]
+    gcp_deployment = get_deployment_config(factory, project_id, deployment_name)
+    config = yaml.safe_load(gcp_deployment.config_content)
 
-        # get manifest
-        manifest = (
-            deployment_client.manifests()
-            .get(
-                project=project_id, deployment=deployment_name, manifest=manifest_name,
-            )
-            .execute()
-        )
-        config = yaml.safe_load(manifest["config"]["content"])
+    # build a resource config with only the bucket
+    resources = list(
+        filter(lambda r: r["type"] == "storage.v1.bucket", config["resources"])
+    )
 
-        # build a resource config with only the bucket
-        resources = list(
-            filter(lambda r: r["type"] == "storage.v1.bucket", config["resources"])
-        )
-
-        # update the deployment
-        deployment = {
-            "name": deployment_name,
-            "fingerprint": fingerprint,
-            "target": {"config": {"content": yaml.dump({"resources": resources}),},},
-        }
-        response = (
-            deployment_client.deployments()
-            .update(project=project_id, deployment=deployment_name, body=deployment)
-            .execute()
-        )
-        wait_for_operation_completion(
-            deployment_client,
-            {"operation": response["name"], "project": project_id},
-            f"Delete deployment {deployment_name}",
-            timeout=600,
-        )
-    except HttpError as e:
-        raise ClickException(
-            f"Failed to delete deployment {deployment_name}. Error: {e}"
-        )
+    # update the deployment
+    updated_config_content = yaml.dump({"resources": resources})
+    update_deployment(
+        factory,
+        project_id,
+        deployment_name,
+        gcp_deployment.fingerprint,
+        updated_config_content,
+    )
 
 
 def remove_firewall_policy_associations(
@@ -599,3 +574,182 @@ def remove_firewall_policy_associations(
             raise ClickException(
                 f"Failed to remove firewall policy association. {response.error}"
             )
+
+
+def get_or_create_memorystore_gcp(
+    factory: GoogleCloudClientFactory,
+    cloud_id: str,
+    deployment_name: str,
+    project_id: str,
+    region: str,
+    logger: CloudSetupLogger,
+    yes: bool = False,
+) -> str:
+    """
+    Get or create Memorystore instance in the deployment.
+    Return the memorystore name in the format of projects/<project number>/locations/<location>/instances/<instance id>
+    """
+    redis_resource_name = f"redis-{deployment_name}"
+
+    # Get redis from deployment
+    redis_instance = get_deployment_resource(
+        factory, project_id, deployment_name, redis_resource_name
+    )
+    if redis_instance is not None:
+        return f"projects/{project_id}/locations/{region}/instances/{redis_instance['name']}"
+
+    # No redis instance found, create one
+    gcp_deployment = get_deployment_config(factory, project_id, deployment_name)
+
+    # Update body with Memorystore
+    params = {
+        "CLOUD_ID": cloud_id.replace("_", "-").lower(),
+        "REGION": region,
+        "PROJECT_ID": project_id,
+    }
+    gcp_memorystore_instance = Template(
+        GCP_MEMORYSTORE_RESOURCE_CONFIG_TEMPLATE
+    ).substitute(params)
+    updated_config_content = gcp_deployment.config_content + gcp_memorystore_instance
+
+    # update the deployment
+    if not yes:
+        # Preview the deployment update
+        with logger.spinner("Creating deployment preview..."):
+            update_deployment(
+                factory,
+                project_id,
+                deployment_name,
+                gcp_deployment.fingerprint,
+                updated_config_content,
+                preview=True,
+            )
+        deployment_url = f"https://console.cloud.google.com/dm/deployments/details/{deployment_name}?project={project_id}"
+        logger.info(f"Please review the changes in the deployment at {deployment_url}")
+        confirm("Continue?", yes)
+
+    with logger.spinner("Updating deployment..."):
+        # Get the fingerprint
+        gcp_deployment = get_deployment_config(factory, project_id, deployment_name)
+        # To update a deployment in preview, we must set the config_content to None
+        update_deployment(
+            factory, project_id, deployment_name, gcp_deployment.fingerprint, None
+        )
+
+    # Get redis from deployment
+    redis_instance = get_deployment_resource(
+        factory, project_id, deployment_name, redis_resource_name
+    )
+    if redis_instance is not None:
+        return f"projects/{project_id}/locations/{region}/instances/{redis_instance['name']}"
+    else:
+        raise ClickException(
+            f"Failed to create Memorystore instance in deployment {deployment_name}. Please contact Anyscale support."
+        )
+
+
+def update_deployment(
+    factory: GoogleCloudClientFactory,
+    project_id: str,
+    deployment_name: str,
+    fingerprint: str,
+    config_content: Optional[str],
+    preview: bool = False,
+):
+    """
+    Update a deployment with the given config.
+    """
+    deployment_client = factory.build("deploymentmanager", "v2")
+    description = "create preview for deployment" if preview else "update deployment"
+    deployment: Dict[str, Any] = {
+        "name": deployment_name,
+        "fingerprint": fingerprint,
+    }
+    if config_content:
+        deployment["target"] = {
+            "config": {"content": config_content},
+        }
+
+    try:
+        response = (
+            deployment_client.deployments()
+            .update(
+                project=project_id,
+                deployment=deployment_name,
+                body=deployment,
+                preview=preview,
+            )
+            .execute()
+        )
+        wait_for_operation_completion(
+            deployment_client,
+            {"operation": response["name"], "project": project_id},
+            f"{description.capitalize()} {deployment_name}",
+            timeout=GCP_DEPLOYMENT_PREVIEW_TIMEOUT_SECONDS
+            if preview
+            else GCP_DEPLOYMENT_MANAGER_TIMEOUT_SECONDS_LONG,
+        )
+    except HttpError as e:
+        raise ClickException(f"Failed to {description} {deployment_name}. Error: {e}")
+
+
+def get_deployment_resource(
+    factory: GoogleCloudClientFactory,
+    project_id: str,
+    deployment_name: str,
+    resource_name: str,
+):
+    """
+    Get a resource from a deployment. If the resource is not found, return None.
+    """
+    deployment_client = factory.build("deploymentmanager", "v2")
+    try:
+        resource = (
+            deployment_client.resources()
+            .get(project=project_id, deployment=deployment_name, resource=resource_name)
+            .execute()
+        )
+        return resource
+    except HttpError as e:
+        if e.status_code == 404:
+            return None
+        raise ClickException(
+            f"Failed to get resource {resource_name} from deployment {deployment_name}: {e}. "
+        )
+
+
+def get_deployment_config(
+    factory: GoogleCloudClientFactory, project_id: str, deployment_name: str
+) -> GCPDeployment:
+    """
+    Get the fingerprint and manifest config from a deployment.
+    """
+    deployment_client = factory.build("deploymentmanager", "v2")
+    try:
+        # get the deployment
+        deployment = (
+            deployment_client.deployments()
+            .get(project=project_id, deployment=deployment_name)
+            .execute()
+        )
+        fingerprint = deployment["fingerprint"]
+        manifest = deployment["manifest"]
+        manifest_name = manifest.split("/")[-1]
+
+        # get manifest
+        manifest = (
+            deployment_client.manifests()
+            .get(
+                project=project_id, deployment=deployment_name, manifest=manifest_name,
+            )
+            .execute()
+        )
+    except HttpError as e:
+        raise ClickException(
+            f"Failed to get deployment config from deployment {deployment_name}: {e}. "
+        )
+    return GCPDeployment(
+        deployment_name=deployment_name,
+        fingerprint=fingerprint,
+        config_content=manifest["config"]["content"],
+    )
