@@ -8,7 +8,8 @@ from anyscale.commands.cloud_commands import register_cloud, setup_cloud
 
 
 @pytest.mark.parametrize("enable_head_node_fault_tolerance", [True, False])
-def test_cloud_setup(enable_head_node_fault_tolerance):
+@pytest.mark.parametrize("yes", [True, False])
+def test_cloud_setup(enable_head_node_fault_tolerance, yes):
     runner = CliRunner()
     mock_cloud_controller = Mock()
     mock_setup_managed_cloud = Mock()
@@ -19,6 +20,8 @@ def test_cloud_setup(enable_head_node_fault_tolerance):
     name = "unit-test-cloud"
 
     args = ["--provider", provider, "--name", name, "--region", region]
+    if yes:
+        args.append("--yes")
 
     if enable_head_node_fault_tolerance:
         args.append("--enable-head-node-fault-tolerance")
@@ -35,6 +38,7 @@ def test_cloud_setup(enable_head_node_fault_tolerance):
         functional_verify=None,
         cluster_management_stack_version=ClusterManagementStackVersions.V2,
         enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
+        yes=yes,
     )
 
 
