@@ -42,6 +42,9 @@ def test_api_client_authenticated(
         with pytest.raises(Exception):  # noqa: PT011
             controller.test_call_anyscale_api_client()
     else:
-        mock_get_auth_api_client.assert_called_once_with()
+        # Assert API expections are not structured (and are wrapped as `click.ClickException`) by default
+        mock_get_auth_api_client.assert_called_once_with(
+            raise_structured_exception=False
+        )
         assert controller.api_client == base_mock_api_client
         assert controller.anyscale_api_client == base_mock_anyscale_api_client
