@@ -1,4 +1,4 @@
-from typing import Iterator, List
+from typing import Iterator, List, Optional
 from unittest.mock import MagicMock, Mock, patch
 
 from click import ClickException
@@ -30,9 +30,21 @@ def mock_auth_api_client(base_mock_anyscale_api_client: Mock) -> Iterator[None]:
 
 
 @pytest.mark.parametrize("cloud_provider", [CloudProviders.AWS, CloudProviders.GCP])
-@pytest.mark.parametrize("compute_config_exists", [True, False])
+@pytest.mark.parametrize(
+    ("is_exception_stream_removed", "timeout", "compute_config_exists"),
+    [
+        pytest.param(None, False, True, id="happy-path-exists"),
+        pytest.param(None, False, False, id="happy-path-create"),
+        pytest.param(True, False, False, id="stream-removed"),
+        pytest.param(False, False, False, id="cannot-create"),
+        pytest.param(True, True, False, id="timeout"),
+    ],
+)
 def test_get_or_create_cluster_compute(
-    compute_config_exists: bool, cloud_provider: CloudProviders,
+    is_exception_stream_removed: Optional[bool],
+    timeout: bool,
+    compute_config_exists: bool,
+    cloud_provider: CloudProviders,
 ) -> None:
     mock_cloud_id = "mock_cloud_id"
     mock_cluster_compute_id = "mock_cluster_compute_id"
@@ -43,19 +55,58 @@ def test_get_or_create_cluster_compute(
         )
     )
     mock_anyscale_api_client = Mock()
-    mock_anyscale_api_client.create_cluster_compute = Mock(
-        return_value=Mock(result=Mock(id=mock_cluster_compute_id))
-    )
-
-    funciontal_verification_controller = CloudFunctionalVerificationController(Mock())
-    funciontal_verification_controller.api_client = mock_api_client
-    funciontal_verification_controller.anyscale_api_client = mock_anyscale_api_client
-    assert (
-        funciontal_verification_controller.get_or_create_cluster_compute(
-            mock_cloud_id, cloud_provider
+    if is_exception_stream_removed is None:
+        mock_anyscale_api_client.create_cluster_compute = Mock(
+            return_value=Mock(result=Mock(id=mock_cluster_compute_id))
         )
-        == mock_cluster_compute_id
-    )
+    elif is_exception_stream_removed is True:
+        mock_anyscale_api_client.create_cluster_compute = Mock()
+        if timeout:
+            mock_anyscale_api_client.create_cluster_compute.side_effect = ClickException(
+                "Stream removed"
+            )
+        else:
+            mock_anyscale_api_client.create_cluster_compute.side_effect = [
+                ClickException("Stream removed"),
+                Mock(result=Mock(id=mock_cluster_compute_id)),
+            ]
+
+    elif is_exception_stream_removed is False:
+        mock_anyscale_api_client.create_cluster_compute = Mock(
+            side_effect=ClickException("mock error")
+        )
+    with patch(
+        "anyscale.controllers.cloud_functional_verification_controller.CREATE_COMPUTE_CONFIG_TIMEOUT_SECONDS",
+        1,
+    ):
+        funciontal_verification_controller = CloudFunctionalVerificationController(
+            Mock()
+        )
+
+        funciontal_verification_controller = CloudFunctionalVerificationController(
+            Mock()
+        )
+        funciontal_verification_controller.api_client = mock_api_client
+        funciontal_verification_controller.anyscale_api_client = (
+            mock_anyscale_api_client
+        )
+        if timeout or (is_exception_stream_removed is False):
+            with pytest.raises(ClickException) as e:
+                funciontal_verification_controller.get_or_create_cluster_compute(
+                    mock_cloud_id, cloud_provider
+                )
+            if timeout:
+                e.match("Timed out")
+            else:
+                e.match("mock error")
+        else:
+
+            assert (
+                funciontal_verification_controller.get_or_create_cluster_compute(
+                    mock_cloud_id, cloud_provider
+                )
+                == mock_cluster_compute_id
+            )
 
     mock_api_client.search_compute_templates_api_v2_compute_templates_search_post.assert_called_with(
         ComputeTemplateQuery(
@@ -69,7 +120,7 @@ def test_get_or_create_cluster_compute(
     if compute_config_exists:
         mock_anyscale_api_client.create_cluster_compute.assert_not_called()
     else:
-        mock_anyscale_api_client.create_cluster_compute.assert_called_once()
+        mock_anyscale_api_client.create_cluster_compute.assert_called()
 
 
 @pytest.mark.parametrize(
@@ -150,7 +201,8 @@ def test_verify_workspace(
 
 
 @pytest.mark.parametrize("create_service_succeed", [True, False])
-def test_rollout_service(create_service_succeed: bool):
+@pytest.mark.parametrize("canary_percent", [None, 100])
+def test_rollout_service(create_service_succeed: bool, canary_percent: Optional[int]):
     mock_cluster_compute_id = "mock_cluster_compute_id"
     mock_cluster_env_build_id = "mock_cluster_env_build_id"
     mock_project_id = "mock_project_id"
@@ -172,7 +224,7 @@ def test_rollout_service(create_service_succeed: bool):
         ),
     ):
         controller = CloudFunctionalVerificationController(Mock())
-        controller.api_client.apply_service_v2_api_v2_services_v2_apply_put = (
+        controller.api_client.apply_service_api_v2_services_v2_apply_put = (
             mock_rollout_service
         )
 
@@ -183,6 +235,7 @@ def test_rollout_service(create_service_succeed: bool):
                     Mock(),
                     version=mock_version,
                     service_name=mock_service_name,
+                    canary_percent=canary_percent,
                 )
         else:
             assert (
@@ -191,6 +244,7 @@ def test_rollout_service(create_service_succeed: bool):
                     Mock(),
                     version=mock_version,
                     service_name=mock_service_name,
+                    canary_percent=canary_percent,
                 ).id
                 == mock_service_id
             )
@@ -213,8 +267,11 @@ def test_rollout_service(create_service_succeed: bool):
                 build_id=mock_cluster_env_build_id,
                 compute_config_id=mock_cluster_compute_id,
                 config=ServiceConfig(
-                    max_uptime_timeout_sec=SERVICE_VERIFICATION_TIMEOUT_MINUTES * 60,
+                    max_uptime_timeout_sec=SERVICE_VERIFICATION_TIMEOUT_MINUTES
+                    * 2
+                    * 60,
                 ),
+                canary_percent=canary_percent,
             )
         )
 
@@ -435,3 +492,39 @@ def test_get_live_console(functions_to_verify):
         assert funciontal_verification_controller.step_progress[function] is not None
         assert funciontal_verification_controller.overall_progress[function] is not None
         assert funciontal_verification_controller.task_ids[function] is not None
+
+
+@pytest.mark.parametrize(
+    ("no_cluster_env", "no_default_cluster_env"),
+    [
+        pytest.param(True, True, id="no-cluster-env"),
+        pytest.param(False, True, id="no-default-cluster-env"),
+        pytest.param(False, False, id="no-default-cluster-env"),
+    ],
+)
+def test_get_default_cluster_env_build_id(no_cluster_env, no_default_cluster_env):
+    mock_cluster_env_list = []
+    mock_build_id = "mock_id"
+    if not no_cluster_env:
+        mock_cluster_env_list.append(
+            MagicMock(
+                is_default=not no_default_cluster_env,
+                latest_build=MagicMock(id=mock_build_id),
+            )
+        )
+        mock_cluster_env_list.append(
+            MagicMock(is_default=False, latest_build=MagicMock(id="mock_id_2"))
+        )
+
+    mock_api_client = Mock()
+    mock_api_client.list_application_templates_api_v2_application_templates_get = Mock(
+        return_value=Mock(results=mock_cluster_env_list)
+    )
+    controller = CloudFunctionalVerificationController(Mock())
+    controller.api_client = mock_api_client
+    if no_cluster_env:
+        with pytest.raises(ClickException) as e:
+            controller.get_default_cluster_env_build_id()
+        e.match("No cluster environments found")
+    else:
+        assert controller.get_default_cluster_env_build_id() == mock_build_id
