@@ -314,7 +314,7 @@ def test_service_rollout(
     Please reference services_internal_api_models.py for more details.
     """
     service_controller = ServiceController()
-    service_controller.api_client.apply_service_v2_api_v2_services_v2_apply_put = Mock(
+    service_controller.api_client.apply_service_api_v2_services_v2_apply_put = Mock(
         return_value=Mock(
             result=(
                 Mock(
@@ -390,7 +390,7 @@ def test_service_rollout(
         config=service_config,
     )
 
-    service_controller.api_client.apply_service_v2_api_v2_services_v2_apply_put.assert_called_once_with(
+    service_controller.api_client.apply_service_api_v2_services_v2_apply_put.assert_called_once_with(
         service_v2_config
     )
 
@@ -796,7 +796,7 @@ def test_override_runtime_env_config_and_infer_project_id_v2(
         service_controller.api_client = Mock()
         service_controller.anyscale_api_client = Mock()
         service_controller.log = Mock()
-        service_controller.api_client.apply_service_v2_api_v2_services_v2_apply_put = (
+        service_controller.api_client.apply_service_api_v2_services_v2_apply_put = (
             Mock()
         )
 
@@ -816,7 +816,7 @@ def test_override_runtime_env_config_and_infer_project_id_v2(
             "runtime_env": new_runtime_env,
         }
 
-        service_controller.api_client.apply_service_v2_api_v2_services_v2_apply_put.assert_called_once_with(
+        service_controller.api_client.apply_service_api_v2_services_v2_apply_put.assert_called_once_with(
             ApplyProductionServiceV2Model(
                 name=config_dict["name"],
                 description=config_dict["description"],
