@@ -33,7 +33,7 @@ def test_format_service_v2_config():
 
     apply_service_config = format_service_config(service_config)
 
-    assert apply_service_config.service_v2_config.project_id == project_id
-    assert apply_service_config.service_v2_config.ray_serve_config == ray_serve_config
-    assert apply_service_config.service_v2_config.version == version
-    assert apply_service_config.service_v2_config.canary_percent == canary_percent
+    assert apply_service_config.project_id == project_id
+    assert apply_service_config.ray_serve_config == ray_serve_config
+    assert apply_service_config.version == version
+    assert apply_service_config.canary_percent == canary_percent
