@@ -2,12 +2,12 @@ import datetime
 from unittest.mock import Mock, patch
 
 from click.exceptions import ClickException
+from freezegun import freeze_time
 import pytest
 
 from anyscale.client.openapi_client import Session, SessionListResponse
 from anyscale.client.openapi_client.models.project import Project
 from anyscale.util import (
-    canonicalize_remote_location,
     credentials_check_sanity,
     deserialize_datetime,
     get_project_directory_name,
@@ -16,44 +16,6 @@ from anyscale.util import (
 )
 
 
-@pytest.mark.parametrize(
-    ("working_dir", "remote_location", "result"),  # type: ignore
-    [
-        ("test-working-dir", "/a/b/c", "/a/b/c"),
-        ("~/test-working-dir", "/root/a/b/c", "~/a/b/c"),
-        ("/root/test-working-dir", "~/a/b/c", "/root/a/b/c"),
-        ("/root/test-working-dir", "/root/a/b/c", "/root/a/b/c"),
-        ("~/test-working-dir", "~/a/b/c", "~/a/b/c"),
-    ],
-)
-def test_canonicalize_remote_location(working_dir, remote_location, result):
-    """Test that canonicalize_remote_location
-    changes remote_location from being based
-    in "~/" or "/root/" to match working_dir.
-    """
-    cluster_config = {
-        "metadata": {"anyscale": {"working_dir": working_dir}},
-        "docker": {"container_name": "test-container-name"},
-    }
-    project_id = "test-project-id"
-    assert (
-        canonicalize_remote_location(cluster_config, remote_location, project_id)
-        == result
-    )
-
-    # Test with "ray" not "root"
-    result_ray = result.replace("root", "ray")
-    cluster_config["metadata"]["anyscale"]["working_dir"] = working_dir.replace(  # type: ignore
-        "root", "ray"
-    )
-    assert (
-        canonicalize_remote_location(
-            cluster_config, remote_location.replace("root", "ray"), project_id
-        )
-        == result_ray
-    )
-
-
 def test_deserialize_datetime() -> None:
     date_str = "2020-07-02T20:16:04.000000+00:00"
     assert deserialize_datetime(date_str) == datetime.datetime(
@@ -97,7 +59,16 @@ def test_wait_for_session_start_terminated(
     mock_api_client_with_session.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
         results=[session_terminated_test_data]
     )
-    with patch("time.sleep", Mock()), pytest.raises(ClickException) as e:
+
+    # Mock time so we don't need to wait 30 real time seconds for terminated
+    # grace period
+    freezer = freeze_time("2023-01-1 12:00:00")
+    freezer.start()
+
+    def sleep_mock(*args, **kwargs):
+        freezer.stop()
+
+    with patch("time.sleep", sleep_mock), pytest.raises(ClickException) as e:
         wait_for_session_start(
             session_terminated_test_data.project_id,
             session_terminated_test_data.id,
@@ -112,6 +83,48 @@ def test_wait_for_session_start_terminated(
     )
 
 
+def test_wait_for_session_start_terminated_grace_period(
+    mock_api_client_with_session: Mock,
+    session_terminated_test_data: Session,
+    session_test_data: Session,
+) -> None:
+    mock_api_client_with_session.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
+        results=[session_terminated_test_data]
+    )
+    """
+    Tests first iteration of loop with session in terminated state. On next iteration, we update
+    the session to be in running state. Since the terminated state happens within the grace period,
+    there should be no error (as opposed to test_wait_for_session_start_terminated)
+    """
+
+    def sleep_mock(*args, **kwargs):
+        mock_api_client_with_session.list_sessions_api_v2_sessions_get.assert_called_with(
+            project_id=session_terminated_test_data.project_id,
+            name=session_terminated_test_data.id,
+            active_only=False,
+        )
+        # Changed mocked response from terminated to running
+        mock_api_client_with_session.list_sessions_api_v2_sessions_get.return_value = SessionListResponse(
+            results=[session_test_data]
+        )
+        mock_api_client_with_session.reset_mock()
+
+    with patch("time.sleep", sleep_mock):
+        result = wait_for_session_start(
+            session_terminated_test_data.project_id,
+            session_terminated_test_data.id,
+            mock_api_client_with_session,
+        )
+
+    assert result == session_test_data.id
+
+    mock_api_client_with_session.list_sessions_api_v2_sessions_get.assert_called_with(
+        project_id=session_test_data.project_id,
+        name=session_test_data.id,
+        active_only=False,
+    )
+
+
 def test_wait_for_session_start_missing_session(
     mock_api_client_with_session: Mock, session_start_error_test_data: Session
 ) -> None:
