@@ -32,6 +32,7 @@ from anyscale.client.openapi_client.models.subnet_id_with_availability_zone_aws
     SubnetIdWithAvailabilityZoneAWS,
 )
 from anyscale.cloud_resource import (
+    is_internal_communication_allowed,
     verify_aws_cloudformation_stack,
     verify_aws_efs,
     verify_aws_iam_roles,
@@ -475,13 +476,16 @@ def test_verify_aws_vpc(
 @pytest.mark.parametrize(
     ("is_private_network"), [False, True],
 )
+@pytest.mark.parametrize(
+    ("assign_public_ip"), [False, True],
+)
 @mock_ec2
-def test_verify_aws_subnets(capsys, is_private_network: bool):
+def test_verify_aws_subnets(capsys, is_private_network: bool, assign_public_ip: bool):
     cloud_resource_mock = generate_cloud_resource_mock_aws()
     region = "us-west-2"
     vpc_id = _create_vpc(region=region)
     subnet_ids = _create_subnets(
-        vpc_id=vpc_id, region=region, assign_public_ip=not is_private_network
+        vpc_id=vpc_id, region=region, assign_public_ip=assign_public_ip
     )
 
     cloud_resource_mock.aws_vpc_id = vpc_id
@@ -497,8 +501,11 @@ def test_verify_aws_subnets(capsys, is_private_network: bool):
     _, stderr = capsys.readouterr()
 
     assert result
-    assert not re.search(
-        r"does not have the 'Auto-assign Public IP' option enabled", stderr
+    assert ("does not have the 'Auto-assign Public IP' option enabled" in stderr) == (
+        not is_private_network and not assign_public_ip
+    )
+    assert ("remove the `--private-network` flag" in stderr) == (
+        is_private_network and assign_public_ip
     )
     assert re.search(r"verification succeeded.", stderr)
 
@@ -960,6 +967,56 @@ def test_verify_aws_security_groups_inbound_permissions(
         assert re.search(expected_log_message, stderr)
 
 
+@pytest.mark.parametrize(
+    ("ip_permissions", "aws_security_group_ids", "expected_result"),
+    [
+        pytest.param(
+            [
+                {
+                    "IpProtocol": "tcp",
+                    "FromPort": 123,
+                    "ToPort": 123,
+                    "IpRanges": [{"CidrIp": "0.0.0.0/10"}],
+                }
+            ],
+            ["mock_group_id"],
+            False,
+        ),
+        pytest.param(
+            [{"IpProtocol": "-1", "UserIdGroupPairs": [{"GroupId": "unknown"}]}],
+            ["mock_group_id"],
+            False,
+        ),
+        pytest.param(
+            [{"IpProtocol": "-1", "UserIdGroupPairs": [{"GroupId": "mock_group_id"}]}],
+            ["mock_group_id"],
+            True,
+        ),
+        pytest.param(
+            [
+                {
+                    "IpProtocol": "-1",
+                    "UserIdGroupPairs": [{"GroupId": "mock_group_id"}],
+                },
+                {
+                    "IpProtocol": "-1",
+                    "UserIdGroupPairs": [{"GroupId": "mock_group_id_2"}],
+                },
+            ],
+            ["mock_group_id", "mock_group_id_3"],
+            True,
+        ),
+    ],
+)
+def test_is_internal_communication_allowed(
+    ip_permissions, aws_security_group_ids, expected_result
+):
+    assert (
+        is_internal_communication_allowed(ip_permissions, aws_security_group_ids)
+        == expected_result
+    )
+
+
 @pytest.mark.parametrize(
     ("security_groups_permissions", "expected_result", "expected_log_message"),
     [
@@ -1287,7 +1344,7 @@ def test_verify_aws_cloudformation_stack(
         "matching_vpc",
         "matching_subnets",
         "has_lru_set",
-        "tls_disabled",
+        "tls_enabled",
         "is_ha",
         "should_raise_exception",
         "expected_result",
@@ -1383,7 +1440,7 @@ def test_verify_aws_cloudformation_stack(
             False,
             False,
             False,
-            "has TLS enabled which is not supported by ray",
+            "Please create a memorydb cluster with TLS enabled",
         ),
         pytest.param(
             True,
@@ -1423,7 +1480,7 @@ def test_verify_aws_memorydb_cluster(  # noqa: PLR0913
     matching_subnets,
     has_lru_set,
     should_raise_exception,
-    tls_disabled,
+    tls_enabled,
     is_ha,
     expected_result,
     expected_log_message,
@@ -1449,7 +1506,7 @@ def test_verify_aws_memorydb_cluster(  # noqa: PLR0913
                     ],
                     "SubnetGroupName": "subnet-group-1234567890",
                     "ParameterGroupName": "parameter-group-1234567890",
-                    "TLSEnabled": True,
+                    "TLSEnabled": False,
                     "Shards": [
                         {
                             "Name": "shard-0001",
@@ -1505,8 +1562,8 @@ def test_verify_aws_memorydb_cluster(  # noqa: PLR0913
             "Parameters": [{"Name": "maxmemory-policy", "Value": "not-allkeys-lru",}]
         }
 
-    if tls_disabled:
-        mock_cluster_resp["Clusters"][0]["TLSEnabled"] = False
+    if tls_enabled:
+        mock_cluster_resp["Clusters"][0]["TLSEnabled"] = True
 
     if is_ha:
         mock_cluster_resp["Clusters"][0]["Shards"][0]["Nodes"].append(
