@@ -52,6 +52,7 @@ def test_get_job_submission_client_cluster_info(
             self._cluster_env_dict = "_cluster_env_dict"
             self._cluster_env_revision = "_cluster_env_revision"
             self._ray = "_ray"
+            self._cluster_compute_version = 2
 
     mock_client_builder = MockClientBuilder()
 
@@ -78,7 +79,11 @@ def test_get_job_submission_client_cluster_info(
 
     if create_cluster_if_needed:
         mock_project_block.assert_called_once_with(
-            mock_client_builder._project_dir, mock_client_builder._project_name
+            mock_client_builder._project_dir,
+            mock_client_builder._project_name,
+            cloud_name=mock_client_builder._cloud_name,
+            cluster_compute_name=mock_client_builder._cluster_compute_name,
+            cluster_compute_dict=mock_client_builder._cluster_compute_dict,
         )
         mock_prepare_cluster_block.assert_called_once_with(
             project_id="mock_project_id",
@@ -96,4 +101,5 @@ def test_get_job_submission_client_cluster_info(
             cluster_env_dict=mock_client_builder._cluster_env_dict,
             cluster_env_revision=mock_client_builder._cluster_env_revision,
             ray=mock_client_builder._ray,
+            cluster_compute_version=mock_client_builder._cluster_compute_version,
         )
