@@ -1,5 +1,8 @@
+from typing import Optional
 from unittest.mock import ANY, Mock
 
+import pytest
+
 from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_default_cluster_compute,
@@ -73,12 +76,16 @@ def test_register_compute_template():
     )
 
 
-def test_get_cluster_compute_from_name():
+@pytest.mark.parametrize("version", [None, 2])
+def test_get_cluster_compute_from_name(version: Optional[int]):
     mock_api_client = Mock()
     mock_api_client.search_compute_templates_api_v2_compute_templates_search_post = Mock(
         return_value=Mock(results=[Mock(id="mock_id")])
     )
-    assert get_cluster_compute_from_name("mock_name", mock_api_client).id == "mock_id"
+    assert (
+        get_cluster_compute_from_name("mock_name", mock_api_client, version).id
+        == "mock_id"
+    )
 
     mock_api_client.search_compute_templates_api_v2_compute_templates_search_post.assert_called_once_with(
         ComputeTemplateQuery(
@@ -86,6 +93,7 @@ def test_get_cluster_compute_from_name():
             name={"equals": "mock_name"},
             include_anonymous=True,
             archive_status=ArchiveStatus.ALL,
+            version=version,
         )
     )
 
