@@ -5,7 +5,7 @@ import re
 import sys
 from tempfile import NamedTemporaryFile
 from typing import Any, Callable, List
-from unittest.mock import Mock, patch
+from unittest.mock import MagicMock, Mock, patch
 
 import click
 from google.api_core.exceptions import NotFound
@@ -39,6 +39,7 @@ from anyscale.gcp_verification import (
     verify_gcp_project,
     verify_memorystore,
 )
+from anyscale.utils.gcp_utils import GCP_REQUIRED_APIS
 from anyscale.utils.network_verification import Direction, FirewallRule, Protocol
 
 
@@ -246,7 +247,7 @@ def test_verify_gcp_project(setup_mock_server, responses, expected_result: bool)
     factory, tracker = setup_mock_server
     tracker.reset(responses)
     assert (
-        verify_gcp_project(factory, _MOCK_GCP_PROJECT_ID, _gcp_logger())
+        verify_gcp_project(factory, MagicMock(), _MOCK_GCP_PROJECT_ID, _gcp_logger())
         == expected_result
     )
 
@@ -262,7 +263,7 @@ def test_verify_gcp_missing_bindigs(setup_mock_server, capsys):
             ]
         }
     )
-    assert verify_gcp_project(factory, _MOCK_GCP_PROJECT_ID, _gcp_logger())
+    assert verify_gcp_project(factory, MagicMock(), _MOCK_GCP_PROJECT_ID, _gcp_logger())
     _, err = capsys.readouterr()
     assert (
         "The Compute Engine Service Agent does not have the standard IAM Role of 'roles/compute.serviceAgent'"
@@ -271,7 +272,7 @@ def test_verify_gcp_missing_bindigs(setup_mock_server, capsys):
 
 
 @pytest.mark.parametrize(
-    ("responses", "expected_result"),
+    ("responses", "yes", "expected_result"),
     [
         pytest.param(
             {
@@ -281,33 +282,71 @@ def test_verify_gcp_missing_bindigs(setup_mock_server, capsys):
                     ("200 OK", "project_apis_enabled.json"),
                 ]
             },
+            False,
             True,
             id="success",
         ),
         pytest.param(
             {
                 ".*": [
-                    ("200 OK", "project_get_inactive.json"),
-                    ("200 OK", "project_apis_enabled.json"),
+                    ("200 OK", "project_get.json"),
+                    ("200 OK", "project_iam_bindings.json"),
+                    ("200 OK", "project_apis_disabled.json"),
                 ]
             },
             False,
-            id="not_enabled",
+            False,
+            id="project-disabled",
+        ),
+        pytest.param(
+            {
+                ".*": [
+                    ("200 OK", "project_get.json"),
+                    ("200 OK", "project_iam_bindings.json"),
+                    ("200 OK", "project_apis_disabled.json"),
+                ]
+            },
+            True,
+            True,
+            id="will-enable-apis",
         ),
     ],
 )
-def test_verify_gcp_project_apis(setup_mock_server, responses, expected_result: bool):
+@pytest.mark.parametrize("has_memorystore", [True, False])
+def test_verify_gcp_project_apis(
+    setup_mock_server,
+    responses,
+    has_memorystore: bool,
+    yes: bool,
+    expected_result: bool,
+):
     factory, tracker = setup_mock_server
     tracker.reset(responses)
+    mock_resource = MagicMock(
+        memorystore_instance_config=Mock() if has_memorystore else None
+    )
+    mock_enable_project_apis = Mock()
     with patch.multiple(
         "anyscale.gcp_verification",
-        enable_project_apis=Mock(),
+        enable_project_apis=mock_enable_project_apis,
         click=Mock(confirm=Mock(return_value=False)),
     ):
         assert (
-            verify_gcp_project(factory, _MOCK_GCP_PROJECT_ID, _gcp_logger(False))
+            verify_gcp_project(
+                factory, mock_resource, _MOCK_GCP_PROJECT_ID, _gcp_logger(yes)
+            )
             == expected_result
         )
+        if yes and expected_result:
+            mock_enable_project_apis.assert_called_once()
+        else:
+            mock_enable_project_apis.assert_not_called()
+        query_str = "".join(
+            [req.get("QUERY_STRING", "") for req in tracker.seen_requests]
+        )
+        for api in GCP_REQUIRED_APIS:
+            assert api in query_str
+        assert has_memorystore == ("redis.googleapis.com" in query_str)
 
 
 @pytest.mark.parametrize(
@@ -663,6 +702,11 @@ def test_verify_cloud_storage(setup_mock_server, responses, expected_result: boo
             False,
             id="readReplicaDisabled",
         ),
+        pytest.param(
+            [("200 OK", "regional_memorystore_tls_enabled.json"),],
+            False,
+            id="tlsDisabled",
+        ),
         pytest.param(
             [("200 OK", "regional_memorystore_happy.json"),], True, id="happy",
         ),
