@@ -683,14 +683,31 @@ def test_gen_valid_name():
 
 
 @pytest.mark.parametrize(
-    ("describe_cluster_response", "raise_exception",),
+    ("describe_cluster_response", "raise_exception", "exception_substr"),
     [
-        pytest.param({}, True),
-        pytest.param({"Clusters": [{}]}, True),
+        pytest.param({}, True, "does not exist"),
+        pytest.param({"Clusters": [{}]}, True, "does not exist"),
         pytest.param(
             {
                 "Clusters": [
                     {
+                        "Status": "creating",
+                        "ARN": "mock_cluster_arn",
+                        "ClusterEndpoint": {
+                            "Address": "mock_cluster_endpoint_address",
+                            "Port": 6379,
+                        },
+                    }
+                ]
+            },
+            True,
+            "not currently available.",
+        ),
+        pytest.param(
+            {
+                "Clusters": [
+                    {
+                        "Status": "available",
                         "ARN": "mock_cluster_arn",
                         "ClusterEndpoint": {
                             "Address": "mock_cluster_endpoint_address",
@@ -700,10 +717,13 @@ def test_gen_valid_name():
                 ]
             },
             False,
+            "",
         ),
     ],
 )
-def test_get_memorydb_cluster_config(describe_cluster_response, raise_exception):
+def test_get_memorydb_cluster_config(
+    describe_cluster_response, raise_exception, exception_substr
+):
 
     mock_memorydb_cluster_id = "mock_memorydb_cluster_id"
     mock_region = "mock_region"
@@ -718,13 +738,15 @@ def test_get_memorydb_cluster_config(describe_cluster_response, raise_exception)
                 _get_memorydb_cluster_config(
                     mock_memorydb_cluster_id, mock_region, Mock()
                 )
-            assert "does not exist." in str(exc_info.value)
+            assert exception_substr in str(exc_info.value)
         else:
             cluster_config = _get_memorydb_cluster_config(
                 mock_memorydb_cluster_id, mock_region, Mock()
             )
             assert cluster_config.id == "mock_cluster_arn"
-            assert cluster_config.endpoint == "mock_cluster_endpoint_address:6379"
+            assert (
+                cluster_config.endpoint == "rediss://mock_cluster_endpoint_address:6379"
+            )
 
 
 @pytest.mark.parametrize(
