@@ -19,6 +19,7 @@ from anyscale.utils.cloud_utils import CloudEventProducer
 @pytest.mark.parametrize("exception", [True, False])
 def test_cloud_event_producer_produce(internal_error, cloud_provider_error, exception):
     mock_api_client = Mock()
+    mock_cli_version = "mock_version"
     mock_cloud_provider = Mock()
     mock_api_client.produce_analytics_event_api_v2_analytics_post = Mock()
     if exception:
@@ -40,7 +41,7 @@ def test_cloud_event_producer_produce(internal_error, cloud_provider_error, exce
         else None
     )
 
-    cloud_event_producer = CloudEventProducer(mock_api_client)
+    cloud_event_producer = CloudEventProducer(mock_cli_version, mock_api_client)
     cloud_event_producer.init_trace_context(Mock(), mock_cloud_provider, Mock())
     mock_event_name = Mock()
     succeeded = not (internal_error or cloud_provider_error)
@@ -62,6 +63,7 @@ def test_cloud_event_producer_produce(internal_error, cloud_provider_error, exce
     mock_api_client.produce_analytics_event_api_v2_analytics_post.assert_called_once_with(
         CreateAnalyticsEvent(
             cloud_analytics_event=CloudAnalyticsEvent(
+                cli_version=mock_cli_version,
                 trace_id=cloud_event_producer.trace_id,
                 cloud_id=cloud_event_producer.cloud_id,
                 succeeded=succeeded,
